==> mono-2.4.3.tar.bz2: mono-2.4.3/mcs/class/System.Messaging/System.Messaging.Design/QueuePathDialog.cs <==
//
// System.Messaging.Design.QueuePathDialog
//
// Authors:
//      Gert Driesen (drieseng@users.sourceforge.net)
//
// (C) 2004 Novell
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.ComponentModel;
using System.Drawing.Design;
using System.Windows.Forms;
//using System.Windows.Forms.Design;

namespace System.Messaging.Design
{
	[MonoTODO]
	public class QueuePathDialog : Form
	{
		[MonoTODO]
		public QueuePathDialog (IServiceProvider provider)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public QueuePathDialog ()//IUIService uiService)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public void ChoosePath ()
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public void DoubleClicked (object source, EventArgs e)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public void SelectQueue (MessageQueue queue)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public string Path {
			get {
				throw new NotImplementedException ();
			}
		}
	}
}

==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/System.Messaging/System.Messaging.Design/QueuePathDialog.cs <==
//
// System.Messaging.Design.QueuePathDialog
//
// Authors:
//      Gert Driesen (drieseng@users.sourceforge.net)
//
// (C) 2004 Novell
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
#if !NO_WINFORMS_DEPENDENCY
using System.ComponentModel;
using System.Drawing.Design;
using System.Windows.Forms;

namespace System.Messaging.Design
{
	[MonoTODO]
	public class QueuePathDialog : Form
	{
		[MonoTODO]
		public QueuePathDialog (IServiceProvider provider)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public QueuePathDialog (System.Windows.Forms.Design.IUIService uiService)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public void ChoosePath ()
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public void DoubleClicked (object source, EventArgs e)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public void SelectQueue (MessageQueue queue)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public string Path {
			get {
				throw new NotImplementedException ();
			}
		}
	}
}
#endif
